@@ -1,15 +1,11 @@
-#
-# NetPacket::ICMP -Decode and encode ICMP (Internet Control Message
-# Protocol) packets.
-
 package NetPacket::ICMP;
 BEGIN {
-  $NetPacket::ICMP::VERSION = '0.43.1';
+  $NetPacket::ICMP::VERSION = '0.43.2';
 }
-
+# ABSTRACT: Assemble and disassemble ICMP (Internet Control Message Protocol) packets. 
 
 use strict;
-use vars qw($VERSION @ISA @EXPORT @EXPORT_OK %EXPORT_TAGS);
+use vars qw( @ISA @EXPORT @EXPORT_OK %EXPORT_TAGS);
 
 
 BEGIN {
@@ -149,15 +145,17 @@ sub checksum {
 
 # autoloaded methods go after the END token (&& pod) below
 
-__END__
+
+
+=pod
 
 =head1 NAME
 
-C<NetPacket::ICMP> - Assemble and disassemble ICMP (Internet Control Message Protocol) packets. 
+NetPacket::ICMP - Assemble and disassemble ICMP (Internet Control Message Protocol) packets. 
 
 =head1 VERSION
 
-version 0.43.1
+version 0.43.2
 
 =head1 SYNOPSIS
 
@@ -242,7 +240,6 @@ ICMP message types:
     ICMP_TSTAMP ICMP_TSTAMPREPLY ICMP_IREQ ICMP_IREQREPLY
     ICMP_MASKREQ ICMP_MASKREPLY
 
-
 =item tags
 
 The following tags group together related exportable items.
@@ -305,15 +302,18 @@ fields.
 
 =head1 COPYRIGHT
 
-This is free software; you can redistribute it and/or modify it 
-under the same terms as the Perl 5 programming language system itself.
-
 Copyright (c) 2001 Tim Potter and Stephanie Wehner.
 
 Copyright (c) 1995,1996,1997,1998,1999 ANU and CSIRO on behalf of 
 the participants in the CRC for Advanced Computational Systems
 ('ACSys').
 
+This module is free software.  You can redistribute it and/or
+modify it under the terms of the Artistic License 2.0.
+
+This program is distributed in the hope that it will be useful,
+but without any warranty; without even the implied warranty of
+merchantability or fitness for a particular purpose.
 
 =head1 AUTHOR
 
@@ -323,4 +323,8 @@ Stephanie Wehner E<lt>atrak@itsx.comE<gt>
 
 =cut
 
-# any real autoloaded methods go after this line
\ No newline at end of file
+
+__END__
+
+
+# any real autoloaded methods go after this line
